[CmdletBinding()]
Param(
  [Parameter(Mandatory=$false,Position=1,HelpMessage="Configuration file")]
   [string]$configurationFile = "Configuration.ps1"
)

Import-Module WebAdministration

function Load-Snapins()
{
  $snapinsToCheck = @("WDeploySnapin3.0")
  $currentSnapins = Get-PSSnapin

  $snapinsToCheck | ForEach-Object `
    {$snapin = $_;
      if(($CurrentSnapins | Where-Object {$_.Name -eq "$snapin"}) -eq $null)
      {
         Write-Host "$snapin snapin not found, loading it"
         Add-PSSnapin $snapin
         Write-Host "$snapin snapin loaded"
      }
    }

  $wdeploySnapin = Get-PSSnapin -Name "WDeploySnapin3.0" -ErrorAction SilentlyContinue
  if (!$wdeploySnapin) 
  {
    Write-Host -foregroundcolor Red "Microsoft Web Deploy snapin was not found and could not be loaded. Microsoft Web Deploy 3.0 is required for this installation, please download Web Deploy from 
    http://www.iis.net/downloads/microsoft/web-deploy and try again. The installation will now exit"
    exit
  }
}

function IsPoolInUse($appPool) {
  $appPool = Get-Item ( Join-Path 'IIS:\AppPools' $appPool ) -ErrorAction SilentlyContinue
  if ( $appPool -ne $null ) {
    $webApplications = Get-ChildItem ("IIS:\Sites\$webSiteName") | where { $_.NodeType -eq "application" }
    $result = $webApplications | where { $_.applicationPool -eq $appPool.Name }
  }

  if ($result -eq $null)
  {
    return $false 
  }
  else
  {
    return $true
  }
}

Load-Snapins

. ./$configurationFile

$webApp = Get-Item "IIS:\sites\$appPath"

Write-Host -foregroundcolor Green Removing application $webApp.Name
$systemDrive = [system.environment]::getenvironmentvariable("SystemDrive")
$physicalPath = $webApp.PhysicalPath -replace "%SystemDrive%", $systemDrive
Remove-Item $physicalPath -recurse
Remove-WebApplication $webApp.Name -site $webSiteName

Write-Host -foregroundcolor Green Removing application pool $appPoolName
$res = IsPoolInUse $appPoolName
if (!$res) 
{
  Remove-WebAppPool $appPoolName
} else
{
  Write-Host -foregroundcolor Yellow "Application pool still in use by other applications, not removing it"
}

Write-Host -foregroundcolor green Deleting the service log file
$pathExists = Test-Path $logFilePath
if (!$pathExists)
{
  New-Item -path $logFilePath -type Directory
}

$dirSeparatorIncluded = $logFilePath.EndsWith("\")
if ($dirSeparatorIncluded)
{
  $logFileLocation = "$logFilePath$logFileName" 
} else
{
  $logFileLocation = "$logFilePath\$logFileName"
}

Remove-Item $logFileLocation -ErrorAction SilentlyContinue

Write-Host Uninstallation finished